@@ -227,7 +227,7 @@ describe 'horizon::wsgi::apache' do
         params.merge!({
           :extra_params  => {
             'add_listen' => false,
-            'docroot' => '/tmp'
+            'docroot'    => '/tmp'
           },
         })
       end
@@ -236,6 +236,30 @@ describe 'horizon::wsgi::apache' do
         :add_listen => false,
         :docroot    => '/tmp'
       )}
+      it { should contain_apache__vhost('horizon_ssl_vhost').with(
+        :add_listen => false,
+        :docroot    => '/tmp'
+      )}
+    end
+
+    context 'with ssl extra parameters' do
+      before do
+        params.merge!({
+          :extra_params  => {
+            'docroot' => '/root1'
+          },
+          :ssl_extra_params  => {
+            'docroot' => '/root2'
+          },
+        })
+      end
+
+      it { should contain_apache__vhost('horizon_vhost').with(
+        :docroot => '/root1'
+      )}
+      it { should contain_apache__vhost('horizon_ssl_vhost').with(
+        :docroot => '/root2'
+      )}
     end
 
     context 'with root_url set to /' do
@@ -359,7 +383,7 @@ describe 'horizon::wsgi::apache' do
       )}
     end
 
-    context 'with listen_ssl and ssl_redirect with a empty root_url' do
+    context 'with listen_ssl and ssl_redirect with an empty root_url' do
       before do
         params.merge!({
           :listen_ssl        => true,
